Changelog
=========

1.1.3 (2020-06-23)
------------------

- Fix dates set in example contents.
  [cekk]


1.1.2 (2020-06-23)
------------------

- Set effective date to example published contents.
  [cekk]


1.1.1 (2020-04-09)
------------------

- Add more properties to users export.
  [cekk]


1.1.0 (2020-04-07)
------------------

- Add export users and groups views.
  [cekk]


1.0.2 (2020-02-18)
------------------

- Several improvements in export contents.
  [cekk]

1.0.1 (2020-02-07)
------------------

- Add install profile for create example contents for import tests.
  [cekk]

1.0.0 (2020-02-05)
------------------

- Heavy refactoring to be more DX compatible
  [eikichi][cekk]

- Add tests
  [cekk]


0.1.2 (2019-09-18)
------------------

- Fixed dependency in function call.
  [daniele]
- Added option for return object in order
- Fixed mapping for collection object
  [eikichi18]
- using id when title is missing for Link objects
  [daniele]


0.1.1 (2019-01-16)
------------------

- Removed redturtle.portlets.inspector dependency.
  [daniele]

0.1.0 (2018-11-23)
------------------

- Added parer extra field info
  [daniele]

- Initial release.
  [cekk]
